#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
import json
from netbluemind.python import serder
from netbluemind.python.client import BaseEndpoint

ISharedMailbox_VERSION = "5.5.3158"


class ISharedMailbox(BaseEndpoint):
    def __init__(self, apiKey, url, domainUid):
        self.url = url
        self.apiKey = apiKey
        self.base = url + '/shared_mailboxes/{domainUid}'
        self.domainUid_ = domainUid
        self.base = self.base.replace('{domainUid}', domainUid)

    def allUids(self):
        postUri = "/_alluids"
        __data__ = None
        __encoded__ = None
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': ISharedMailbox_VERSION}, data=__encoded__)
        return self.handleResult__(serder.ListSerDer(serder.STRING), response)

    def byEmail(self, email):
        postUri = "/byEmail/{email}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{email}", email)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': ISharedMailbox_VERSION}, data=__encoded__)
        from netbluemind.user.api.SharedMailbox import SharedMailbox
        from netbluemind.user.api.SharedMailbox import __SharedMailboxSerDer__
        from netbluemind.core.container.model.ItemValue import ItemValue
        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
        return self.handleResult__(__ItemValueSerDer__(__SharedMailboxSerDer__()), response)

    def byName(self, login):
        postUri = "/byName/{login}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{login}", login)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': ISharedMailbox_VERSION}, data=__encoded__)
        from netbluemind.user.api.SharedMailbox import SharedMailbox
        from netbluemind.user.api.SharedMailbox import __SharedMailboxSerDer__
        from netbluemind.core.container.model.ItemValue import ItemValue
        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
        return self.handleResult__(__ItemValueSerDer__(__SharedMailboxSerDer__()), response)

    def delete(self, uid):
        postUri = "/{uid}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        queryParams = {}

        response = requests.delete(self.base + postUri, params=queryParams, verify=False, headers={
                                   'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': ISharedMailbox_VERSION}, data=__encoded__)
        from netbluemind.core.task.api.TaskRef import TaskRef
        from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
        return self.handleResult__(__TaskRefSerDer__(), response)

    def getComplete(self, uid):
        postUri = "/{uid}/complete"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': ISharedMailbox_VERSION}, data=__encoded__)
        from netbluemind.user.api.SharedMailbox import SharedMailbox
        from netbluemind.user.api.SharedMailbox import __SharedMailboxSerDer__
        from netbluemind.core.container.model.ItemValue import ItemValue
        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
        return self.handleResult__(__ItemValueSerDer__(__SharedMailboxSerDer__()), response)

    def getLight(self, uid):
        postUri = "/{uid}/light"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': ISharedMailbox_VERSION}, data=__encoded__)
        from netbluemind.user.api.SharedMailbox import SharedMailbox
        from netbluemind.user.api.SharedMailbox import __SharedMailboxSerDer__
        from netbluemind.core.container.model.ItemValue import ItemValue
        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
        return self.handleResult__(__ItemValueSerDer__(__SharedMailboxSerDer__()), response)

    def getVCard(self, uid):
        postUri = "/{uid}/vcard"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': ISharedMailbox_VERSION}, data=__encoded__)
        from netbluemind.addressbook.api.VCard import VCard
        from netbluemind.addressbook.api.VCard import __VCardSerDer__
        return self.handleResult__(__VCardSerDer__(), response)



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
import json
from netbluemind.python import serder
from netbluemind.python.client import BaseEndpoint

IInternalCredentials_VERSION = "5.5.3158"


class IInternalCredentials(BaseEndpoint):
    def __init__(self, apiKey, url, domainUid):
        self.url = url
        self.apiKey = apiKey
        self.base = url + '/credentials/{domainUid}'
        self.domainUid_ = domainUid
        self.base = self.base.replace('{domainUid}', domainUid)

    def addTotpCredential(self, totpCredential):
        postUri = "/user/totp"
        __data__ = None
        __encoded__ = None
        from netbluemind.system.api.TotpCredential import TotpCredential
        from netbluemind.system.api.TotpCredential import __TotpCredentialSerDer__
        __data__ = __TotpCredentialSerDer__().encode(totpCredential)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IInternalCredentials_VERSION}, data=__encoded__)
        return self.handleResult__(serder.STRING, response)

    def addUserCredential(self, userUid, credential):
        postUri = "/user/{userUid}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{userUid}", userUid)
        from netbluemind.system.api.Credential import Credential
        from netbluemind.system.api.Credential import __CredentialSerDer__
        __data__ = __CredentialSerDer__().encode(credential)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IInternalCredentials_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def addUserCredentials(self, userUid, credentials):
        postUri = "/user/{userUid}/_credentials"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{userUid}", userUid)
        from netbluemind.system.api.Credential import Credential
        from netbluemind.system.api.Credential import __CredentialSerDer__
        __data__ = serder.ListSerDer(
            __CredentialSerDer__()).encode(credentials)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IInternalCredentials_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def getDomainCredentialById(self, credentialId):
        postUri = "/{credentialId}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{credentialId}", credentialId)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IInternalCredentials_VERSION}, data=__encoded__)
        return self.handleResult__(serder.STRING, response)

    def getObfuscatedUserCredentials(self, userUid):
        postUri = "/user/{userUid}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{userUid}", userUid)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IInternalCredentials_VERSION}, data=__encoded__)
        from netbluemind.system.api.Credential import Credential
        from netbluemind.system.api.Credential import __CredentialSerDer__
        from netbluemind.core.api.ListResult import ListResult
        from netbluemind.core.api.ListResult import __ListResultSerDer__
        return self.handleResult__(__ListResultSerDer__(__CredentialSerDer__()), response)

    def getSelfObfuscatedCredentials(self):
        postUri = "/user/_credentials/_self"
        __data__ = None
        __encoded__ = None
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IInternalCredentials_VERSION}, data=__encoded__)
        from netbluemind.system.api.Credential import Credential
        from netbluemind.system.api.Credential import __CredentialSerDer__
        from netbluemind.core.api.ListResult import ListResult
        from netbluemind.core.api.ListResult import __ListResultSerDer__
        return self.handleResult__(__ListResultSerDer__(__CredentialSerDer__()), response)

    def getUserCredentials(self, userUid):
        postUri = "/user/{userUid}/plain"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{userUid}", userUid)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IInternalCredentials_VERSION}, data=__encoded__)
        from netbluemind.system.api.Credential import Credential
        from netbluemind.system.api.Credential import __CredentialSerDer__
        return self.handleResult__(serder.ListSerDer(__CredentialSerDer__()), response)

    def removeSelfCredential(self, credentialId):
        postUri = "/user/_credentials/{credentialId}/_self"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{credentialId}", credentialId)
        queryParams = {}

        response = requests.delete(self.base + postUri, params=queryParams, verify=False, headers={
                                   'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IInternalCredentials_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def removeUserCredential(self, userUid, credentialId):
        postUri = "/user/{userUid}/{credentialId}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{userUid}", userUid)
        postUri = postUri.replace("{credentialId}", credentialId)
        queryParams = {}

        response = requests.delete(self.base + postUri, params=queryParams, verify=False, headers={
                                   'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IInternalCredentials_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def validateTotpCredential(self, totpCredential):
        postUri = "/user/totp/validate"
        __data__ = None
        __encoded__ = None
        from netbluemind.system.api.TotpCredential import TotpCredential
        from netbluemind.system.api.TotpCredential import __TotpCredentialSerDer__
        __data__ = __TotpCredentialSerDer__().encode(totpCredential)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IInternalCredentials_VERSION}, data=__encoded__)
        return self.handleResult__(serder.BOOLEAN, response)



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder


class VEventRange:
    def __init__(self):
        self.dateMin = None
        self.dateMax = None
        pass


class __VEventRangeSerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = VEventRange()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        from netbluemind.core.api.date.BmDateTime import BmDateTime
        from netbluemind.core.api.date.BmDateTime import __BmDateTimeSerDer__
        dateMinValue = value['dateMin']
        instance.dateMin = __BmDateTimeSerDer__().parse(dateMinValue)
        from netbluemind.core.api.date.BmDateTime import BmDateTime
        from netbluemind.core.api.date.BmDateTime import __BmDateTimeSerDer__
        dateMaxValue = value['dateMax']
        instance.dateMax = __BmDateTimeSerDer__().parse(dateMaxValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):

        from netbluemind.core.api.date.BmDateTime import BmDateTime
        from netbluemind.core.api.date.BmDateTime import __BmDateTimeSerDer__
        dateMinValue = value.dateMin
        instance["dateMin"] = __BmDateTimeSerDer__().encode(dateMinValue)
        from netbluemind.core.api.date.BmDateTime import BmDateTime
        from netbluemind.core.api.date.BmDateTime import __BmDateTimeSerDer__
        dateMaxValue = value.dateMax
        instance["dateMax"] = __BmDateTimeSerDer__().encode(dateMaxValue)
        return instance



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder


class SearchResult:
    def __init__(self):
        self.results = None
        self.totalResults = None
        self.hasMoreResults = None
        pass


class __SearchResultSerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = SearchResult()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        from netbluemind.backend.mail.api.MessageSearchResult import MessageSearchResult
        from netbluemind.backend.mail.api.MessageSearchResult import __MessageSearchResultSerDer__
        resultsValue = value['results']
        instance.results = serder.ListSerDer(
            __MessageSearchResultSerDer__()).parse(resultsValue)
        totalResultsValue = value['totalResults']
        instance.totalResults = serder.INT.parse(totalResultsValue)
        hasMoreResultsValue = value['hasMoreResults']
        instance.hasMoreResults = serder.BOOLEAN.parse(hasMoreResultsValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):

        from netbluemind.backend.mail.api.MessageSearchResult import MessageSearchResult
        from netbluemind.backend.mail.api.MessageSearchResult import __MessageSearchResultSerDer__
        resultsValue = value.results
        instance["results"] = serder.ListSerDer(
            __MessageSearchResultSerDer__()).encode(resultsValue)
        totalResultsValue = value.totalResults
        instance["totalResults"] = serder.INT.encode(totalResultsValue)
        hasMoreResultsValue = value.hasMoreResults
        instance["hasMoreResults"] = serder.BOOLEAN.encode(hasMoreResultsValue)
        return instance



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder


class FolderCounters:
    def __init__(self):
        self.itemId = None
        self.recordsVersion = None
        self.unseenVisible = None
        self.totalVisible = None
        self.total = None
        pass


class __FolderCountersSerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = FolderCounters()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        itemIdValue = value['itemId']
        instance.itemId = serder.LONG.parse(itemIdValue)
        recordsVersionValue = value['recordsVersion']
        instance.recordsVersion = serder.LONG.parse(recordsVersionValue)
        unseenVisibleValue = value['unseenVisible']
        instance.unseenVisible = serder.INT.parse(unseenVisibleValue)
        totalVisibleValue = value['totalVisible']
        instance.totalVisible = serder.INT.parse(totalVisibleValue)
        totalValue = value['total']
        instance.total = serder.INT.parse(totalValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):

        itemIdValue = value.itemId
        instance["itemId"] = serder.LONG.encode(itemIdValue)
        recordsVersionValue = value.recordsVersion
        instance["recordsVersion"] = serder.LONG.encode(recordsVersionValue)
        unseenVisibleValue = value.unseenVisible
        instance["unseenVisible"] = serder.INT.encode(unseenVisibleValue)
        totalVisibleValue = value.totalVisible
        instance["totalVisible"] = serder.INT.encode(totalVisibleValue)
        totalValue = value.total
        instance["total"] = serder.INT.encode(totalValue)
        return instance



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder


class Credential:
    def __init__(self):
        self.id = None
        self.type = None
        self.label = None
        self.created = None
        self.secret = None
        self.credential = None
        pass


class __CredentialSerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = Credential()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        idValue = value['id']
        instance.id = serder.STRING.parse(idValue)
        typeValue = value['type']
        instance.type = serder.STRING.parse(typeValue)
        labelValue = value['label']
        instance.label = serder.STRING.parse(labelValue)
        createdValue = value['created']
        instance.created = serder.LONG.parse(createdValue)
        secretValue = value['secret']
        instance.secret = serder.STRING.parse(secretValue)
        credentialValue = value['credential']
        instance.credential = serder.STRING.parse(credentialValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):

        idValue = value.id
        instance["id"] = serder.STRING.encode(idValue)
        typeValue = value.type
        instance["type"] = serder.STRING.encode(typeValue)
        labelValue = value.label
        instance["label"] = serder.STRING.encode(labelValue)
        createdValue = value.created
        instance["created"] = serder.LONG.encode(createdValue)
        secretValue = value.secret
        instance["secret"] = serder.STRING.encode(secretValue)
        credentialValue = value.credential
        instance["credential"] = serder.STRING.encode(credentialValue)
        return instance



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder


class SortDescriptor:
    def __init__(self):
        self.fields = None
        self.filter = None
        pass


class __SortDescriptorSerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = SortDescriptor()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        from netbluemind.core.container.model.SortDescriptorField import SortDescriptorField
        from netbluemind.core.container.model.SortDescriptorField import __SortDescriptorFieldSerDer__
        fieldsValue = value['fields']
        instance.fields = serder.ListSerDer(
            __SortDescriptorFieldSerDer__()).parse(fieldsValue)
        from netbluemind.core.container.model.ItemFlagFilter import ItemFlagFilter
        from netbluemind.core.container.model.ItemFlagFilter import __ItemFlagFilterSerDer__
        filterValue = value['filter']
        instance.filter = __ItemFlagFilterSerDer__().parse(filterValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):

        from netbluemind.core.container.model.SortDescriptorField import SortDescriptorField
        from netbluemind.core.container.model.SortDescriptorField import __SortDescriptorFieldSerDer__
        fieldsValue = value.fields
        instance["fields"] = serder.ListSerDer(
            __SortDescriptorFieldSerDer__()).encode(fieldsValue)
        from netbluemind.core.container.model.ItemFlagFilter import ItemFlagFilter
        from netbluemind.core.container.model.ItemFlagFilter import __ItemFlagFilterSerDer__
        filterValue = value.filter
        instance["filter"] = __ItemFlagFilterSerDer__().encode(filterValue)
        return instance



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

from netbluemind.mailbox.api.rules.actions.MailFilterRuleAction import MailFilterRuleAction
from netbluemind.mailbox.api.rules.actions.MailFilterRuleAction import __MailFilterRuleActionSerDer__


class MailFilterRuleActionRedirect (MailFilterRuleAction):
    def __init__(self):
        MailFilterRuleAction.__init__(self)
        self.emails = None
        self.keepCopy = None
        pass


class __MailFilterRuleActionRedirectSerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = MailFilterRuleActionRedirect()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        __MailFilterRuleActionSerDer__().parseInternal(value, instance)
        emailsValue = value['emails']
        instance.emails = serder.ListSerDer(serder.STRING).parse(emailsValue)
        keepCopyValue = value['keepCopy']
        instance.keepCopy = serder.BOOLEAN.parse(keepCopyValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):
        __MailFilterRuleActionSerDer__().encodeInternal(value, instance)

        emailsValue = value.emails
        instance["emails"] = serder.ListSerDer(
            serder.STRING).encode(emailsValue)
        keepCopyValue = value.keepCopy
        instance["keepCopy"] = serder.BOOLEAN.encode(keepCopyValue)
        return instance
